﻿using System;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Ink;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Diagnostics;

namespace SelectAllMvvm.Assets
{
    public delegate void Execute(object parameter);

    public delegate bool CanExecute(object parameter);

    public class GenericCommand : ICommand
    {
        private Execute _executeMethod;

        private CanExecute _canExecuteMethod;

        #region Constructors
        [DebuggerNonUserCode]
        public GenericCommand()
            : this(null, null)
        {
        }
        [DebuggerNonUserCode]
        public GenericCommand(Execute executeMethod)
            : this(executeMethod, null)
        {
        }
        [DebuggerNonUserCode]
        public GenericCommand(Execute executeMethod, CanExecute canExecuteMethod)
        {
            _executeMethod = executeMethod;
            _canExecuteMethod = canExecuteMethod;
        }

        #endregion
        [DebuggerNonUserCode]
        public bool CanExecute(object parameter)
        {
            if (_canExecuteMethod == null)
            {
                return true;
            }
            else
            {
                return _canExecuteMethod(parameter);
            }
        }

        public event EventHandler CanExecuteChanged;
        [DebuggerNonUserCode]
        public void Execute(object parameter)
        {
            if (_executeMethod != null)
            {
                _executeMethod(parameter);
            }
        }
    }
}
